@@ -4,9 +4,9 @@
 #' Computes the negative entropy criterion (NEC) to assess the number of clusters
 #' in a mixture model. See References for details.
 #'
-#' @param weight_matrix \eqn{N \times K} weight matrix
-#' @param loglik_1 baseline log-likelihood for \eqn{K=1} cluster model
-#' @param loglik_k log-likelihood for \eqn{K} cluster model
+#' @param weight.matrix \eqn{N \times K} weight matrix
+#' @param loglik.1 baseline log-likelihood for \eqn{K=1} cluster model
+#' @param loglik.k log-likelihood for \eqn{K} cluster model
 #' @references
 #' Christophe Biernacki, Gilles Celeux, and G\'erand Govaert(1999). 
 #' ``An improvement of the NEC criterion for assessing the number of clusters 
@@ -19,10 +19,12 @@
 #' WW = normalize(WW)
 #' compute_NEC(WW, -2, -1)
 
-compute_NEC <- function(weight_matrix, loglik_1 = NULL, loglik_k = NULL){
-  if (is.null(loglik_1) | is.null(loglik_k)){
-    stop("You must provide log-likelihoods for 1-cluster and (!) 
+compute_NEC <- function(weight.matrix, loglik.1 = NULL, loglik.k = NULL){
+  if (is.null(loglik.1) || is.null(loglik.k)){
+    stop("You must provide the log-likelihoods for 1-cluster and (!) 
          K-cluster solution.")
   }
-  return(compute_mixture_penalty(weight_matrix, "entropy")/(loglik_k-loglik_1))
+  diff.in.loglik <- loglik.k - loglik.1
+  nec <- compute_mixture_penalty(weight.matrix, "entropy") / diff.in.loglik
+  return(nec)
 }
